[![logo](https://www.hongsnet.net/images/logo.gif)](https://www.hongsnet.net)

# Jenkins Container Image Deploy Overview

> GitLab Project의 Push Event 발생 시 Jenkins가 이를 배포해주는 과정을 살펴본다.

**!참고** : GitLab Webhook 설정은 생략한다. 만약 확인이 필요하다면, 다음의 링크를 참조한다.

[바로가기](./DEVOPS/WEBHOOK/)


# Jenkins Pipeline Script Configuration

> Jenkins 프로젝트 > 구성 > Pipeline 에서 설정한다.

```
import java.text.SimpleDateFormat

def dateFormat = new SimpleDateFormat("yyyyMMdd")
def date = new Date()
 

pipeline {
   agent any
   
   environment {
        TODAY = dateFormat.format(date)
    }
    
   stages {
   
      stage('Git Clone') {
             
            steps {
                //echo 'Clone'
                sh 'mkdir -p docker_hongsnet'
                dir("docker_hongsnet")
                {
                     git branch: 'master', credentialsId: 'juhanida21', url: 'https://gitlab.hongsnet.net/joohan.hong/docker_hongsnet.git'
                }
            }
      }
      
      stage('Container Image Build and Push') {
            steps {
                //sh 'echo ${TODAY}'
                sh 'sudo /usr/bin/docker login -u admin -p 패스워드 harbor.hongsnet.net'
                sh 'cd docker_test; sudo /usr/bin/docker build --rm -t hongsnet .'
                sh 'sudo /usr/bin/docker tag hongsnet:latest harbor.hongsnet.net/hongsnet/hongsnet:${TODAY}_${BUILD_ID}'
                sh 'sudo /usr/bin/docker push harbor.hongsnet.net/hongsnet/hongsnet:${TODAY}_${BUILD_ID}'
                
            }
      }

      stage('K8s Rolling Update') {
            steps {
                sh 'curl -sS http://K8S-MASTER:15999/api/rollup?deployment=hongsnet-web\'&\'cimage=harbor.hongsnet.net/hongsnet/hongsnet:${TODAY}_${BUILD_ID}'
            }
      }
      
   }
}

```

# Pipeline Script Description


## Source Code Deploy 시 세 가지 Stage로 진행된다.

  - **Git Clone**
    - **Jenkins** 시스템에서 최신의 내용을 /GIT/docker_hongsnet 경로로 Pull 한 후 Container Image를 Build한다.
  - **Container Image Build and Push**
    - **Jenkins** 시스템에서 harbor.hongsnet.net, Private Registry에 로그인을 수행
    - Build 된 Container Image를 **Tagging** 한다.
    - Tagging된 Container Image를 저장소에 **Push** 한다.
  - **K8s Rolling Update**
    - **Jenkins** 시스템에서 업데이트 이미지에 대해 `Rolling Update`를 수행한다.
    - **K8S-MASTER:15999**는 직접 Golang을 사용한 RESTful API 이다.


![container_deploy](./container_deploy.png)


